@@ -1,31 +1,30 @@
 import sys
-import tkinter
 from tkinter import Menu
 from tkinter import Text
 from tkinter import Tk
 from tkinter import ttk
 
 from je_editor.ui.ui_event.auto_save.start_auto_save.start_auto_save import start_auto_save
-from je_editor.ui.ui_event.close.close_event import close_event
-from je_editor.ui.ui_event.execute.execute_code.exec_code import execute_code
-from je_editor.ui.ui_event.execute.execute_shell_command.run_on_shell import execute_shell_command
-from je_editor.ui.ui_event.open_file.open_file_to_read.open_file_to_read import open_file_to_read
-from je_editor.ui.ui_event.open_file.open_last_edit_file.open_last_edit_file import open_last_edit_file
-from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_to_open
-from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_then_can_run
-from je_editor.ui.ui_event.tag_keyword.tag_keyword import HighlightText
-from je_editor.ui.ui_utils.editor_content.content_save import open_content_and_start
-from je_editor.ui.ui_event.text_process.program_exec.exec_text import ExecManager
-from je_editor.ui.ui_event.text_process.program_exec.process_error import process_error_text
-from je_editor.ui.ui_utils.font.font import get_font
 from je_editor.ui.ui_event.change_font.change_font import change_font
 from je_editor.ui.ui_event.change_font.change_font import change_font_size
-from je_editor.ui.ui_event.execute.execute_code.exec_code import stop_program
-from je_editor.ui.ui_utils.encoding.encoding_data_module import encoding_list
+from je_editor.ui.ui_event.close.close_event import close_event
 from je_editor.ui.ui_event.encoding.set_encoding import set_encoding
+from je_editor.ui.ui_event.execute.execute_code.exec_code import execute_code
+from je_editor.ui.ui_event.execute.execute_code.exec_code import stop_program
+from je_editor.ui.ui_event.execute.execute_shell_command.run_on_shell import execute_shell_command
 from je_editor.ui.ui_event.language.set_language import set_language
-from je_editor.ui.ui_utils.language.language_data_module import language_list
+from je_editor.ui.ui_event.open_file.open_file_to_read.open_file_to_read import open_file_to_read
+from je_editor.ui.ui_event.open_file.open_last_edit_file.open_last_edit_file import open_last_edit_file
+from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_then_can_run
+from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_to_open
+from je_editor.ui.ui_event.tag_keyword.tag_keyword import HighlightText
+from je_editor.ui.ui_event.text_process.program_exec.exec_text import ExecManager
+from je_editor.ui.ui_event.text_process.program_exec.process_error import process_error_text
+from je_editor.ui.ui_utils.editor_content.content_save import open_content_and_start
 from je_editor.ui.ui_utils.editor_content.editor_data import editor_data_dict
+from je_editor.ui.ui_utils.encoding.encoding_data_module import encoding_list
+from je_editor.ui.ui_utils.font.font import get_font
+from je_editor.ui.ui_utils.language.language_data_module import language_list
 from je_editor.ui.ui_utils.language_data_module.language_compiler_data_module import language_compiler
 from je_editor.ui.ui_utils.language_data_module.language_param_data_module import language_compiler_param
 from je_editor.utils.exception.je_editor_exceptions import JEditorContentFileException
@@ -86,10 +85,11 @@ class EditorMain(object):
                     editor_data_dict["theme"] = self.file_from_output_content.get(
                         "theme")
                 if self.file_from_output_content.get("language") is not None:
-                    language = self.file_from_output_content.get("language")
-                    if language not in language_list:
-                        language_list.append(language)
-                    set_language(self.exec_manager, language)
+                    language_from_content = self.file_from_output_content.get("language")
+                    for language in language_from_content:
+                        if language not in language_list:
+                            language_list.append(language)
+                    set_language(self.exec_manager, language_from_content)
                 if self.file_from_output_content.get("encoding") is not None:
                     set_encoding(self.exec_manager, self.file_from_output_content.get("encoding"))
                 if self.file_from_output_content.get("font") is not None:
@@ -122,19 +122,22 @@ class EditorMain(object):
         except JEditorContentFileException as error:
             print(repr(error), file=sys.stderr)
         self.highlight_text.search()
+        print("language_compiler_param: " + str(language_compiler_param))
+        print("language_compiler: " + str(language_compiler))
+        print("language_list: " + str(language_list))
 
     # default event
     def do_test(self, event=None):
-        self.test_run = True
+        self.debug_run = True
         print("test")
 
-    def __init__(self, use_theme=None, main_window=Tk()):
+    def __init__(self, use_theme=None, debug=False, main_window=Tk()):
         """
         :param use_theme: what theme editor used
         :param main_window: Tk instance
         """
         # is this test run?
-        self.test_run = False
+        self.debug_run = debug
         # Auto save thread
         self.auto_save_thread = None
         # current file
@@ -173,24 +176,25 @@ class EditorMain(object):
         )
         self.main_window.bind(
             "<Control-Key-F6>",
-            lambda bind_exec_shell_command: execute_shell_command(self.program_run_result_textarea, self.code_editor_textarea)
+            lambda bind_exec_shell_command: execute_shell_command(self.program_run_result_textarea,
+                                                                  self.code_editor_textarea)
         )
         # Menubar
         # Main menu
-        self.menu = tkinter.Menu(self.main_window)
+        self.menu = Menu(self.main_window)
         # File menu
-        self.file_menu = tkinter.Menu(self.menu, tearoff=0)
+        self.file_menu = Menu(self.menu, tearoff=0)
         # Text menu
-        self.text_menu = tkinter.Menu(self.menu, tearoff=0)
-        self.text_font_sub_menu = tkinter.Menu(self.text_menu, tearoff=0)
-        self.text_size_sub_menu = tkinter.Menu(self.text_menu, tearoff=0)
+        self.text_menu = Menu(self.menu, tearoff=0)
+        self.text_font_sub_menu = Menu(self.text_menu, tearoff=0)
+        self.text_size_sub_menu = Menu(self.text_menu, tearoff=0)
         self.font_tuple = get_font(self.main_window)
         self.text_menu.add_cascade(label="Font", menu=self.text_font_sub_menu)
         self.text_menu.add_cascade(label="Font Size", menu=self.text_size_sub_menu)
         # Encoding menu
-        self.encoding_menu = tkinter.Menu(self.menu, tearoff=0)
+        self.encoding_menu = Menu(self.menu, tearoff=0)
         # Language menu
-        self.language_menu = tkinter.Menu(self.menu, tearoff=0)
+        self.language_menu = Menu(self.menu, tearoff=0)
         # Popup menu
         self.popup_menu = Menu(self.main_window, tearoff=0)
         self.popup_menu.add_separator()
@@ -261,7 +265,8 @@ class EditorMain(object):
         for i in range(12, 36, 2):
             self.text_size_sub_menu.add_command(
                 label=str(i),
-                command=lambda font_size=i: change_font_size(self.code_editor_textarea, self.program_run_result_textarea,
+                command=lambda font_size=i: change_font_size(self.code_editor_textarea,
+                                                             self.program_run_result_textarea,
                                                              font_size)
             )
         # Language menu
@@ -285,7 +290,14 @@ class EditorMain(object):
         self.menu.add_cascade(label="Encoding", menu=self.encoding_menu)
         self.menu.add_cascade(label="Language", menu=self.language_menu)
         self.main_window.config(menu=self.menu)
+        if self.debug_run:
+            self.close_event()
+
+    def use_choose_theme(self, use_theme=None):
+        self.style.theme_use(use_theme)
 
 
-def start_editor(use_theme=None):
-    EditorMain(use_theme=use_theme).start_editor()
+def start_editor(use_theme=None, **kwargs):
+    new_editor = EditorMain(use_theme=use_theme, **kwargs)
+    new_editor.start_editor()
+    return new_editor
